@@ -1179,7 +1179,6 @@ int
 main(int argc,
      char **argv)
 {
-    SettingsPanel *panel = g_new0(SettingsPanel, 1);
     GtkWidget *settings_dialog = NULL;
     GtkWidget *notifyd_running;
     GtkBuilder *builder;
@@ -1189,7 +1188,7 @@ main(int argc,
     GOptionEntry option_entries[] = {
         { "version", 'V', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &opt_version, N_("Display version information"), NULL },
         { "socket-id", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT, &opt_socket_id, N_("Settings manager socket"), N_("SOCKET_ID") },
-        { NULL, },
+        { NULL, '\0', 0, 0, NULL, NULL, NULL },
     };
     GError *error = NULL;
 
@@ -1242,6 +1241,7 @@ main(int argc,
         return EXIT_FAILURE;
     }
 
+    SettingsPanel *panel = g_new0(SettingsPanel, 1);
     panel->channel = xfconf_channel_new("xfce4-notifyd");
     xfce_notify_migrate_settings(panel->channel);
 
